/*
 * Copyright (c) 2015, Freescale Semiconductor, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of Freescale Semiconductor, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*!
**  @addtogroup pin_mux_module pin_mux module documentation
**  @{
*/

/* MODULE pin_mux. */

#include "device_imx.h"
#include "pin_mux.h"

void configure_flexcan_pins(CAN_Type* base)
{
    switch((uint32_t)base)
    {
        case CAN1_BASE:
            /*CAN 1 is not used in due to pinmux conflicts with I2C */
            break;
        case CAN2_BASE:
            // CAN2_TX
            IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA = IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE(2);
            IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA = IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE_MASK |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS(3)   |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE(0)  |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS_MASK;
			IOMUXC_FLEXCAN2_RX_SELECT_INPUT = IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY(1);

            // CAN2_RX
            IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL = IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE(2);
            IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL = IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE_MASK |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS(3)   |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE(0)  |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS_MASK;
            break;
    }
}

void configure_i2c_pins(I2C_Type* base)
{
    switch((uint32_t)base)
    {
        case I2C1_BASE:
            // I2C1 iomux configuration
            IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL = IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE(0) |
                                             IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION_MASK;
            IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA = IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE(0) |
                                             IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION_MASK;

            IOMUXC_I2C1_SCL_SELECT_INPUT = IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY(1);
            IOMUXC_I2C1_SDA_SELECT_INPUT = IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY(1);

            IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL = IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE_MASK  |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS(3)    |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE(0)   |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS_MASK;

            IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA = IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE_MASK  |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS(3)    |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE(0)   |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS_MASK;
            break;
        case I2C2_BASE:
            // I2C2 iomux configuration
            IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06 = IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(0) |
													IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION_MASK;
            IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07 = IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(0) |
            										IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION_MASK;

            IOMUXC_I2C2_SCL_SELECT_INPUT = IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY(2);
            IOMUXC_I2C2_SDA_SELECT_INPUT = IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY(2);

            IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06 = IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE_MASK  |
            										IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS(3)    |
													IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(0)   |
													IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS_MASK;

            IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07 = IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE_MASK  |
            										IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS(3)    |
													IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(0)   |
													IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS_MASK;
            break;
        case I2C3_BASE:
            // I2C3 iomux configuration
            IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 = IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(4) |
                                 	 	 	   IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION_MASK;
            IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 = IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(4) |
                                   	   	   	   IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION_MASK;

            IOMUXC_I2C3_SCL_SELECT_INPUT = IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY(0);
            IOMUXC_I2C3_SDA_SELECT_INPUT = IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY(0);

            IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 = IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE_MASK  |
                                               IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS(3)    |
                                               IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(0)   |
                                               IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS_MASK;

            IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 = IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE_MASK  |
                                               IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS(3)    |
                                               IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(0)   |
                                               IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS_MASK;
            break;
        case I2C4_BASE:
            // I2C4 iomux configuration
            IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL = IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE(0) |
                                                 IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION_MASK;
            IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA = IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE(0) |
                                                 IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION_MASK;

            IOMUXC_I2C4_SCL_SELECT_INPUT = IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY(2);
            IOMUXC_I2C4_SDA_SELECT_INPUT = IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY(2);

            IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL = IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE_MASK  |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS(3)    |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE(0)   |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS_MASK;

            IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA = IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE_MASK  |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS(3)    |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE(0)   |
                                             IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS_MASK;
            break;
        default:
            break;
    }
}

void configure_uart_pins(UART_Type* base)
{
    switch((uint32_t)base)
    {
        case UART2_BASE:
            // UART2 iomux configuration
        	IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE = IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE(4);
        	IOMUXC_SW_MUX_CTL_PAD_LCD_CLK = IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE(4);
        	IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE = IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE_MASK |
        									   IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS(3) |
											   IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS_MASK |
											   IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE(0);
        	IOMUXC_SW_PAD_CTL_PAD_LCD_CLK = IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE_MASK |
        	        						IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS(3) |
        									IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS_MASK |
        									IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE(0);
        	IOMUXC_UART2_RX_DATA_SELECT_INPUT = IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY(0);
            break;
        default:
            break;
    }
}

/*******************************************************************************
 * EOF
 ******************************************************************************/
